@@ -1,10 +1,14 @@
+"""
+Templatetags
+"""
 import re
-from django.conf import settings
 from django.template import Library, TemplateSyntaxError
-from sorl.thumbnail import default, get_thumbnail
+from sorl.thumbnail import get_thumbnail
 from sorl.thumbnail.images import DummyImageFile
 from sorl.thumbnail.templatetags.thumbnail import ThumbnailNode
 
+from ..settings import THUMBNAIL_MAKER_FORMATS
+
 
 register = Library()
 
@@ -30,8 +34,12 @@ class UseThumbnailNode(ThumbnailNode):
 
     def _render(self, context):
         file_ = self.file_.resolve(context)
+        # geometry here is a name of thumb format
         geometry = self.geometry.resolve(context)
-        geometry, options = file_.field.thumbs.get(geometry)
+        # now get actual geometry string for sorl-thumbnail
+        geometry, options = THUMBNAIL_MAKER_FORMATS.get(
+            geometry, ('', {})
+        )
         thumbnail = get_thumbnail(file_, geometry, **options)
 
         if not thumbnail or (isinstance(thumbnail, DummyImageFile) and
@@ -57,4 +65,9 @@ class UseThumbnailNode(ThumbnailNode):
 
 @register.tag
 def usethumbnail(parser, token):
+    """
+    Return thumbnailed image, just like `thumbnail` templatetag
+    from sorl-thumbnail, but using thumbnail's pre-defined format name
+    instead of geometry and does not accept any other parameters.
+    """
     return UseThumbnailNode(parser, token)
